# Support and Help

Need help getting started or using a project? Here's how.

## How to get help

Generally, we do not use GitHub as a support forum. For any usage questions that are not specific to the project itself, please ask on [Stack Overflow](https://stackoverflow.com) instead. By doing so, you are more likely to quickly solve your problem, and you will allow anyone else with the same question to find the answer. This also allows maintainers to focus on improving the project for others.

Please seek support in the following ways:

1. :book: **Read the documentation and other guides** for the project to see if you can figure it out on your own. These should be located in a root `docs/` directory. If there is an example project, explore that to learn how it works to see if you can answer your question.

1. :bulb: **Search for answers and ask questions on [Stack Overflow](https://stackoverflow.com).** This is the most appropriate place for debugging issues specific to your use of the project, or figuring out how to use the project in a specific way.

1. :memo: As a **last resort**, you may open an issue on GitHub to ask for help. However, please clearly explain what you are trying to do, and list what you have already attempted to solve the problem. Provide code samples, but **do not** attach your entire project for someone else to debug. Review our [contributing guidelines](https://github.com/Tanukie/tanuki.py/.github/blob/master/CONTRIBUTING.md).

1. :speech_balloon: **Chat with us on [Discord](https://img.shields.io/discord/1168948553222197248).** This is a great place to ask questions and get help from the community. Please do not DM maintainers directly, as they are likely busy and will not respond.
## What NOT to do 

Please **do not** do any the following:

1. :x: Do not reach out to the author or contributor on Twitter (or other social media) by tweeting or sending a direct message.

1. :x: Do not email the author or contributor.

1. :x: Do not open duplicate issues or litter an existing issue with +1's.

These are not appropriate avenues for seeking help or support with an open-source project. Please follow the guidelines in the previous section. Public questions get public answers, which benefits everyone in the community. ✌️

## Customer Support

We do not provide any sort of "customer support" for open-source projects. However, we will often be willing to help over on our Discord, below:

![Discord](https://img.shields.io/discord/1168948553222197248)